#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-KFJMUlnbaY28GGguhdQ7Lp
key:                  http-streams-0.8.9.9-KFJMUlnbaY28GGguhdQ7Lp
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  f8b8235305be52a134e741f0493c4358
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-KFJMUlnbaY28GGguhdQ7Lp
depends:
    HsOpenSSL-0.11.7.10-E6Zp7QGcfDi7RFhtYd6KkS
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    attoparsec-0.14.4-9B3gn5pX08KJB1CStsvQz6
    attoparsec-aeson-2.2.0.1-IvTxK5zEibXC9zeDxF2mLE base-4.18.2.1
    base64-bytestring-1.2.1.0-KV8aVMC7eDp4VhaST1z1XE
    blaze-builder-0.4.4.1-Ffv3SgR0MZVINK2hZ9J6eQ bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-2SnL7ivoQpJysduP4hT1S
    io-streams-1.5.2.2-52a6WRm7JQwBOijvu9lUyh mtl-2.3.1
    network-3.1.4.0-6Vir8NKcwTtGDZOkjzNXEQ
    network-uri-2.6.4.2-9CHKirNVw9rJ9Z87o3gbmr
    openssl-streams-1.2.3.0-9Pe6WSXaNmsFDyr8WMRbAP text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-IS42DvcTPVH3F2RDVwits

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

